@@ -40,11 +40,11 @@ def tear_down():
 def t():
   setup()
   expectation = set([
-    './_list_filepaths/_/abc.txt',
-    './_list_filepaths/_/bar.py',
-    './_list_filepaths/_',
-    './_list_filepaths/xyz.txt',
-    './_list_filepaths/foo.py'
+    f'{temp_dir_1}/abc.txt',
+    f'{temp_dir_1}/bar.py',
+    f'{temp_dir_1}',
+    f'{temp_dir_0}/xyz.txt',
+    f'{temp_dir_0}/foo.py'
   ])
   observation = set(f(temp_dir_0))
   test_result = expectation == observation
