@@ -16,9 +16,9 @@ def f(directory, filepaths=[]):
 
   rmdir(directory)
 
-temp_dir = './_'
+temp_dir = './temp_directory_remove'
 temp_files_and_content = [
-  (f'{temp_dir}/foo.py', 'f = lambda: None\nt = lambda: f() is None'),
+  (f'{temp_dir}/foo.py', 'run = lambda: None\ntest = lambda: run() is None'),
   (f'{temp_dir}/xyz.txt', 'xyz'),
 ]
 
